@@ -537,7 +537,7 @@ impl TryFrom<tx_by_addr::TransactionError> for TransactionError {
                     47 => InstructionError::ArithmeticOverflow,
                     48 => InstructionError::UnsupportedSysvar,
                     49 => InstructionError::IllegalOwner,
-                    50 => InstructionError::AccountsDataBudgetExceeded,
+                    50 => InstructionError::MaxAccountsDataSizeExceeded,
                     51 => InstructionError::ActiveVoteAccountClose,
                     _ => return Err("Invalid InstructionError"),
                 };
@@ -826,8 +826,8 @@ impl From<TransactionError> for tx_by_addr::TransactionError {
                             InstructionError::IllegalOwner => {
                                 tx_by_addr::InstructionErrorType::IllegalOwner
                             }
-                            InstructionError::AccountsDataBudgetExceeded => {
-                                tx_by_addr::InstructionErrorType::AccountsDataBudgetExceeded
+                            InstructionError::MaxAccountsDataSizeExceeded => {
+                                tx_by_addr::InstructionErrorType::MaxAccountsDataSizeExceeded
                             }
                             InstructionError::ActiveVoteAccountClose => {
                                 tx_by_addr::InstructionErrorType::ActiveVoteAccountClose
